"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMinLength = exports.getMaxLength = exports.getEnumList = exports.enumRuleIsActive = exports.ruleIsNotApplicable = exports.ruleIsApplicable = exports.ruleIsActive = exports.ruleIsDisabled = void 0;
const types_1 = require("@commitlint/types");
function ruleIsDisabled(rule) {
    if (rule && Array.isArray(rule) && rule[0] === types_1.RuleConfigSeverity.Disabled) {
        return true;
    }
    return false;
}
exports.ruleIsDisabled = ruleIsDisabled;
/**
 * Check if a rule definition is active
 * @param rule to check
 * @return if the rule definition is active
 */
function ruleIsActive(rule) {
    if (rule && Array.isArray(rule)) {
        return rule[0] > types_1.RuleConfigSeverity.Disabled;
    }
    return false;
}
exports.ruleIsActive = ruleIsActive;
/**
 * Check if a rule definition is applicable
 * @param rule to check
 * @return if the rule definition is applicable
 */
function ruleIsApplicable(rule) {
    if (rule && Array.isArray(rule)) {
        return rule[1] === 'always';
    }
    return false;
}
exports.ruleIsApplicable = ruleIsApplicable;
/**
 * Check if a rule definition is applicable
 * @param rule to check
 * @return if the rule definition is applicable
 */
function ruleIsNotApplicable(rule) {
    if (rule && Array.isArray(rule)) {
        return rule[1] === 'never';
    }
    return false;
}
exports.ruleIsNotApplicable = ruleIsNotApplicable;
function enumRuleIsActive(rule) {
    return (ruleIsActive(rule) &&
        ruleIsApplicable(rule) &&
        Array.isArray(rule[2]) &&
        rule[2].length > 0);
}
exports.enumRuleIsActive = enumRuleIsActive;
function getEnumList(rule) {
    return Array.isArray(rule[2]) ? rule[2] : [];
}
exports.getEnumList = getEnumList;
function getMaxLength(rule) {
    if (rule &&
        ruleIsActive(rule) &&
        ruleIsApplicable(rule) &&
        typeof rule[2] === 'number') {
        return rule[2];
    }
    return Infinity;
}
exports.getMaxLength = getMaxLength;
function getMinLength(rule) {
    if (rule &&
        ruleIsActive(rule) &&
        ruleIsApplicable(rule) &&
        typeof rule[2] === 'number') {
        return rule[2];
    }
    return 0;
}
exports.getMinLength = getMinLength;
//# sourceMappingURL=rules.js.map